#pragma once

void writeUnitInfo();
void writeColorInfo();
void writeWeaponInfo();
void writeUpgradeInfo();
void writeUnitSizeInfo();
void writeUnitCommandInfo();
void writeTechInfo();
void writeRaceInfo();
void writePlayerTypeInfo();
void writeOrderInfo();
void writeGameTypeInfo();
void writeExplosionTypeInfo();
void writeDamageTypeInfo();
void writeBulletTypeInfo();
void writeErrorInfo();

void genUnitTypeTest();



